@@ -32,6 +32,7 @@
 #include <dbus/dbus-glib.h>
 
 #include "bluetooth-client.h"
+#include "bluetooth-client-private.h"
 #include "bluetooth-client-glue.h"
 
 #include "marshal.h"
@@ -404,6 +405,20 @@ device_list_nodes (DBusGProxy *device, BluetoothClient *client, gboolean connect
 	return table;
 }
 
+static const char *
+uuid16_custom_to_string (guint uuid16, const char *uuid)
+{
+	switch (uuid16) {
+	case 0x2:
+		return "SyncMLClient";
+	case 0x5601:
+		return "Nokia SyncML Server";
+	default:
+		g_debug ("Unhandled custom UUID %s (0x%x)", uuid, uuid16);
+		return NULL;
+	}
+}
+
 /* Short names from Table 2 at:
  * https://www.bluetooth.org/Technical/AssignedNumbers/service_discovery.htm */
 static const char *
@@ -420,6 +435,8 @@ uuid16_to_string (guint uuid16, const char *uuid)
 		return "OBEXObjectPush";
 	case 0x1106:
 		return "OBEXFileTransfer";
+	case 0x1108:
+		return "HSP";
 	case 0x110A:
 		return "AudioSource";
 	case 0x110B:
@@ -436,16 +453,29 @@ uuid16_to_string (guint uuid16, const char *uuid)
 		return "NAP";
 	case 0x1117:
 		return "GN";
+	case 0x111e:
+		return "Handsfree";
 	case 0x111F:
 		return "HandsfreeAudioGateway";
 	case 0x1124:
 		return "HumanInterfaceDeviceService";
+	case 0x112d:
+		return "SIM_Access";
 	case 0x112F:
 		return "Phonebook_Access_-_PSE";
+	case 0x1203:
+		return "GenericAudio";
 	case 0x1000: /* ServiceDiscoveryServerServiceClassID */
 	case 0x1200: /* PnPInformation */
 		/* Those are ignored */
 		return NULL;
+	case 0x1201:
+		return "GenericNetworking";
+	case 0x8e771303:
+	case 0x8e771301:
+		return "SEMC HLA";
+	case 0x8e771401:
+		return "SEMC Watch Phone";
 	default:
 		g_debug ("Unhandled UUID %s (0x%x)", uuid, uuid16);
 		return NULL;
@@ -457,6 +487,10 @@ bluetooth_uuid_to_string (const char *uuid)
 {
 	char **parts;
 	guint uuid16;
+	gboolean is_custom = FALSE;
+
+	if (g_str_has_suffix (uuid, "-0000-1000-8000-0002ee000002") != FALSE)
+		is_custom = TRUE;
 
 	parts = g_strsplit (uuid, "-", -1);
 	if (parts == NULL || parts[0] == NULL) {
@@ -469,7 +503,9 @@ bluetooth_uuid_to_string (const char *uuid)
 	if (uuid16 == 0)
 		return NULL;
 
-	return uuid16_to_string (uuid16, uuid);
+	if (is_custom == FALSE)
+		return uuid16_to_string (uuid16, uuid);
+	return uuid16_custom_to_string (uuid16, uuid);
 }
 
 static char **
@@ -1353,13 +1389,14 @@ static void create_device_callback(DBusGProxy *proxy,
 	dbus_g_proxy_end_call(proxy, call, &error,
 			DBUS_TYPE_G_OBJECT_PATH, &path, G_TYPE_INVALID);
 
-	if (error != NULL) {
+	if (error != NULL)
 		path = NULL;
-		g_error_free(error);
-	}
 
 	if (devdata->func)
-		devdata->func(devdata->client, path, devdata->data);
+		devdata->func(devdata->client, path, error, devdata->data);
+
+	if (error != NULL)
+		g_error_free (error);
 
 	g_object_unref (devdata->client);
 	g_object_unref(proxy);
