@@ -32,6 +32,7 @@
 #include <dbus/dbus-glib.h>
 
 #include <bluetooth-client.h>
+#include <bluetooth-client-private.h>
 #include <bluetooth-killswitch.h>
 #include <bluetooth-chooser.h>
 #include <bluetooth-plugin-manager.h>
@@ -175,13 +176,13 @@ static gboolean show_confirm_dialog(const char *name)
 
 	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
 					 GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
-					 _("Remove '%s' from list of known devices?"), name);
+					 _("Remove '%s' from the list of devices?"), name);
 	g_object_set (G_OBJECT (dialog), "secondary-text",
-		      _("If you delete the device, you have to set it up again before next use."),
+		      _("If you remove the device, you will have to set it up again before next use."),
 		      NULL);
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_DELETE, GTK_RESPONSE_ACCEPT);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_REMOVE, GTK_RESPONSE_ACCEPT);
 
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -193,7 +194,7 @@ static gboolean show_confirm_dialog(const char *name)
 	return FALSE;
 }
 
-static void delete_callback(GtkWidget *button, gpointer user_data)
+static void remove_callback(GtkWidget *button, gpointer user_data)
 {
 	adapter_data *adapter = user_data;
 	GValue value = { 0, };
@@ -348,7 +349,7 @@ static void create_adapter(adapter_data *adapter)
 	gtk_box_pack_start(GTK_BOX(mainbox), vbox, FALSE, TRUE, 0);
 
 	/* The discoverable checkbox */
-	button = gtk_check_button_new_with_mnemonic (_("_Discoverable"));
+	button = gtk_check_button_new_with_mnemonic (_("Make computer _discoverable"));
 	if (powered == FALSE)
 		discoverable = FALSE;
 	if (discoverable != FALSE && timeout == 0)
@@ -401,7 +402,7 @@ static void create_adapter(adapter_data *adapter)
 	table = gtk_table_new(2, 2, FALSE);
 	gtk_box_pack_start(GTK_BOX(mainbox), table, TRUE, TRUE, 0);
 
-	label = create_label(_("Known devices"));
+	label = create_label(_("Devices"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 2, 0, 1,
 			 GTK_EXPAND | GTK_FILL, GTK_SHRINK, 0, 6);
 
@@ -433,7 +434,7 @@ static void create_adapter(adapter_data *adapter)
 	gtk_table_attach(GTK_TABLE(table), buttonbox, 1, 2, 1, 2,
 			 GTK_FILL, GTK_FILL, 6, 6);
 
-	button = gtk_button_new_with_label(_("Setup new device..."));
+	button = gtk_button_new_with_label(_("Setup _new device..."));
 	image = gtk_image_new_from_stock(GTK_STOCK_ADD,
 						GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_image(GTK_BUTTON(button), image);
@@ -456,8 +457,8 @@ static void create_adapter(adapter_data *adapter)
 
 	adapter->button_disconnect = button;
 
-	button = gtk_button_new_with_label(_("Delete"));
-	image = gtk_image_new_from_stock(GTK_STOCK_DELETE,
+	button = gtk_button_new_with_mnemonic(_("_Remove"));
+	image = gtk_image_new_from_stock(GTK_STOCK_REMOVE,
 						GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_image(GTK_BUTTON(button), image);
 	gtk_box_pack_end(GTK_BOX(buttonbox), button, FALSE, FALSE, 0);
@@ -466,7 +467,7 @@ static void create_adapter(adapter_data *adapter)
 	gtk_widget_set_sensitive(button, FALSE);
 
 	g_signal_connect(G_OBJECT(button), "clicked",
-				G_CALLBACK(delete_callback), adapter);
+				G_CALLBACK(remove_callback), adapter);
 
 	adapter->button_delete = button;
 
